@@ -103,6 +103,8 @@ class DynamicResource {
     public static final String labelSuffix = "Label";
     /** name constant for action commands in the resource file */
     private static final String actionSuffix = "Action";
+    /** name constant for accelerators in the resource file */
+    public static final String acceleratorSuffix = "Accelerator";
     /** name constant for indicating image resources in the resource file */
     public static final String imageSuffix = "Image";
     /** name constant for tool tip strings in the resource file */
