@@ -34,6 +34,7 @@ import java.util.*;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeEvent;
 
+import com.lightdev.app.shtm.SHTMLEditorKitActions.ChangeFontSizeAction.Change;
 import com.lightdev.app.shtm.SHTMLEditorKitActions.SetStyleAction;
 import com.lightdev.app.shtm.SHTMLEditorKitActions.SetTagAction;
 import java.util.prefs.*;
@@ -161,11 +162,19 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
     public static final String fontAction = "font";
     public static final String fontFamilyAction = "fontFamily";
     public static final String fontSizeAction = "fontSize";
+    public static final String increaseFontSizeAction = "increaseFontSize";
+    public static final String decreaseFontSizeAction = "decreaseFontSize";
     public static final String fontBoldAction = "fontBold";
     public static final String fontStrikethroughAction = "fontStrikethrough";
     public static final String fontItalicAction = "fontItalic";
     public static final String fontUnderlineAction = "fontUnderline";
     public static final String fontColorAction = "fontColor";
+    public static final String removeFontColorAction = "removeFontColor";
+    public static final String selectedFontColorAction = "selectedFontColor";
+    public static final String redFontColorAction = "redFontColor";
+    public static final String blueFontColorAction = "blueFontColor";
+    public static final String blackFontColorAction = "blackFontColor";
+    public static final String greenFontColorAction = "greenFontColor";
     public static final String helpTopicsAction = "helpTopics";
     public static final String aboutAction = "about";
     public static final String gcAction = "gc";
@@ -697,6 +706,9 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
         addAction(fontAction, new SHTMLEditorKitActions.FontAction(this));
         addAction(fontFamilyAction, new SHTMLEditorKitActions.FontFamilyAction(this));
         addAction(fontSizeAction, new SHTMLEditorKitActions.FontSizeAction(this));
+        addAction(increaseFontSizeAction, new SHTMLEditorKitActions.ChangeFontSizeAction(this, increaseFontSizeAction, Change.INCREASE));
+        addAction(decreaseFontSizeAction, new SHTMLEditorKitActions.ChangeFontSizeAction(this, decreaseFontSizeAction, Change.DECREASE));
+        
         addAction(insertTableAction, new SHTMLEditorKitActions.InsertTableAction(this));
         addAction(insertTableRowAction, new SHTMLEditorKitActions.InsertTableRowAction(this, null,
             insertTableRowAction));
@@ -716,7 +728,14 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
         addAction(fontBoldAction, new SHTMLEditorKitActions.BoldAction(this));
         addAction(fontItalicAction, new SHTMLEditorKitActions.ItalicAction(this));
         addAction(fontUnderlineAction, new SHTMLEditorKitActions.UnderlineAction(this));
-        addAction(fontColorAction, new SHTMLEditorKitActions.FontColorAction(this));
+        addAction(fontColorAction, new SHTMLEditorKitActions.FontColorByDialogAction(this));
+        addAction(selectedFontColorAction, new SHTMLEditorKitActions.SelectedFontColorAction(this));
+        addAction(redFontColorAction, new SHTMLEditorKitActions.FixedFontColorAction(this, redFontColorAction, Color.RED));
+        addAction(greenFontColorAction, new SHTMLEditorKitActions.FixedFontColorAction(this, greenFontColorAction, new Color(0, 0x80, 0)));
+        addAction(blueFontColorAction, new SHTMLEditorKitActions.FixedFontColorAction(this, blueFontColorAction, new Color(0, 0, 0xc0)));
+        addAction(blackFontColorAction, new SHTMLEditorKitActions.FixedFontColorAction(this, blackFontColorAction, new Color(0, 0, 0)));
+        addAction(removeFontColorAction, new SHTMLEditorKitActions.RemoveStyleAttributeAction(this, removeFontColorAction, HTML.Attribute.COLOR, CSS.Attribute.COLOR));
+        
         addAction(fontStrikethroughAction, new SHTMLEditorKitActions.ApplyCSSAttributeAction(this,
             fontStrikethroughAction, CSS.Attribute.TEXT_DECORATION, "line-through", false));
         addAction(paraAlignLeftAction, new SHTMLEditorKitActions.ApplyCSSAttributeAction(this,
@@ -1056,6 +1075,10 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
     }
   }
 
+    public boolean isWYSIWYGEditorActive() {
+        return getDocumentPane() != null && editorPane != null && getDocumentPane().getSelectedTab() == DocumentPane.VIEW_TAB_LAYOUT;
+    }
+
     public boolean isHtmlEditorActive() {
         return getDocumentPane() != null && getDocumentPane().getSelectedTab() == DocumentPane.VIEW_TAB_HTML;
     }
@@ -1083,6 +1106,10 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
             action.putValue(Action.SHORT_DESCRIPTION, toolTip);
         }
         
+        final String accelerator = Util.getResourceString(textResources, cmd + DynamicResource.acceleratorSuffix);
+        if (accelerator != null) {
+            action.putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(accelerator));
+        }
     }
 
     /* ---------- undo/redo implementation ----------------------- */
